@@ -1,11 +1,12 @@
 /*
- * Copyright © 2010 Linaro
+ * Copyright © 2010-2011 Linaro Limited
  *
  * This file is part of the glmark2 OpenGL (ES) 2.0 benchmark.
  *
  * glmark2 is free software: you can redistribute it and/or modify it under the
- * terms of the GNU General Public License version 3, as published by the Free
- * Software Foundation.
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
  * glmark2 is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -18,8 +19,8 @@
  * Authors:
  *  Alexandros Frantzis (glmark2)
  */
-#ifndef _MATRIX_H
-#define _MATRIX_H
+#ifndef GLMARK2_MATRIX_H_
+#define GLMARK2_MATRIX_H_
 
 #include "oglsdl.h"
 
