@@ -1,12 +1,13 @@
 /*
  * Copyright © 2008 Ben Smith
- * Copyright © 2010 Linaro
+ * Copyright © 2010-2011 Linaro Limited
  *
  * This file is part of the glmark2 OpenGL (ES) 2.0 benchmark.
  *
  * glmark2 is free software: you can redistribute it and/or modify it under the
- * terms of the GNU General Public License version 3, as published by the Free
- * Software Foundation.
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
  * glmark2 is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -20,8 +21,8 @@
  *  Ben Smith (original glmark benchmark)
  *  Alexandros Frantzis (glmark2)
  */
-#ifndef _OGLSDL_H
-#define _OGLSDL_H
+#ifndef GLMARK2_OGLSDL_H_
+#define GLMARK2_OGLSDL_H_
 
 #include <SDL/SDL.h>
 
